@@ -253,6 +253,7 @@ class InstallWindow(wx.Frame):
         position += self.filterscaption.GetSize()[0]+10
 
         self.testingChk = wx.CheckBox(self.panelItems, 401, pos=(position,82-71), size=wx.DefaultSize)
+        self.testingChk.SetValue(True)
         position += 15+self.search_offset
         self.testingCapt = wx.StaticText(self.panelItems, -1, _("Testing"), (position,82-71+self.search_offset), wx.DefaultSize)
         position += self.testingCapt.GetSize()[0]+10
@@ -278,9 +279,19 @@ class InstallWindow(wx.Frame):
         self.stars = 0
         #self.content =  wx.TextCtrl(self.panelItems, 107, pos=(220,301), size=(562,212), style = wx.TE_MULTILINE | wx.TE_RICH2 | wx.CB_READONLY | Variables.widget_borders)
         self.content = PyClickableHtmlWindow(self.panelItems, 107, style=Variables.widget_borders, pos=(580,113-71), size=(200,218))
-        self.button = wx.Button(self.panelItems, wx.ID_CLOSE, _("Cancel"), pos=(736-160, 510-71), size=(100,35))
-        self.install_button = wx.Button(self.panelItems, wx.ID_APPLY, _("Install"), pos=(843-160, 510-71), size=(100,35))
-        self.update_button = wx.Button(self.panelItems, wx.ID_REFRESH, _("Refresh"), pos=(630-160, 510-71), size=(100,35))
+        
+        if(os.environ["POL_OS"] == "Linux"):
+            self.button = wx.Button(self.panelItems, wx.ID_CLOSE, _("Cancel"), pos=(736-160, 510-71), size=(100,35))
+            self.install_button = wx.Button(self.panelItems, wx.ID_APPLY, _("Install"), pos=(843-160, 510-71), size=(100,35))
+            self.update_button = wx.Button(self.panelItems, wx.ID_REFRESH, _("Refresh"), pos=(630-160, 510-71), size=(100,35))
+        else:
+            self.button = wx.Button(self.panelItems, wx.ID_CLOSE, _("Cancel"), pos=(736-160-10, 510-71-8), size=(100,35))
+            self.install_button = wx.Button(self.panelItems, wx.ID_APPLY, _("Install"), pos=(843-160-10, 510-71-8), size=(100,35))
+            self.update_button = wx.Button(self.panelItems, wx.ID_REFRESH, _("Refresh"), pos=(630-160-10, 510-71-8), size=(100,35))
+        
+        
+        
+        
         self.install_button.Enable(False)
 
         self.new_panel = wx.Panel(self.panelItems, -1, pos=(740-160,113-71), style=Variables.widget_borders, size=self.new_size)
@@ -290,7 +301,7 @@ class InstallWindow(wx.Frame):
         self.new_panel.Hide()
 
 
-        self.ManualInstall = wx.HyperlinkCtrl(self.panelItems, 111, _("Install a non-listed program"), "", pos=(10,515-71))
+        self.ManualInstall = wx.HyperlinkCtrl(self.panelFenp, 111, _("Install a non-listed program"), "", pos=(10,515))
         self.ManualInstall.SetNormalColour(wx.Colour(0,0,0))
 
         # Panel wait
@@ -428,7 +439,7 @@ class InstallWindow(wx.Frame):
                 playonlinux.SetSettings("FIRST_INSTALL_DONE","TRUE")
 
             if(os.path.exists(Variables.playonlinux_rep+"/configurations/listes/search")):
-                content = open(Variables.playonlinux_rep+"/configurations/listes/search","r").read().split("\n")
+                content = codecs.open(Variables.playonlinux_rep+"/configurations/listes/search", "r", "utf-8").read().split("\n")
                 found = False
                 for line in content:
                     split = line.split("~")
@@ -510,15 +521,18 @@ class InstallWindow(wx.Frame):
                 free = int(app_array[3])
                 testing = int(app_array[1])
                 nocd = int(app_array[2])
-                show = True
-                if(int(nocd) == 1 and self.nocdChk.IsChecked() == 0):
-                    show = False
-                if(int(free) == 0 and self.freeChk.IsChecked() == 0):
-                    show = False
-                if(int(testing) == 1 and self.testingChk.IsChecked() == 0):
-                    show = False
-            except:
-                show = True
+            except IndexError:
+                free = 0
+                testing = 0
+                nocd = 0
+                
+            show = True
+            if nocd == 1 and self.nocdChk.IsChecked() == 0:
+                show = False
+            if free == 0 and self.freeChk.IsChecked() == 0:
+                show = False
+            if testing == 1 and self.testingChk.IsChecked() == 0:
+                show = False
 
             if(show == True):
                 self.icon_look_for = Variables.playonlinux_rep+"/configurations/icones/"+appname
@@ -529,7 +543,11 @@ class InstallWindow(wx.Frame):
                         pass
                 else:
                     self.imagesapps.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/playonlinux22.png"))
-                self.list_apps.AppendItem(self.root_apps, appname, self.i)
+                itemId = self.list_apps.AppendItem(self.root_apps, appname, self.i)
+                if testing == 1:
+                    # (255,255,214) is web site color for beta, but it's not very visible next to plain white,
+                    # and red is the color of danger
+                    self.list_apps.SetItemBackgroundColour(itemId, (255,214,214))
                 self.i = self.i+1
 
     def DelApps(self):
